@@ -711,14 +711,32 @@ def _elements_to_kwargs(elements, fix_texture, image, prefer_color=None):
     if "vertex" in elements:
         kwargs["vertex_colors"] = _element_colors(elements["vertex"])
 
-    if "edge" in elements:
-        # this is a Path element.
+    # check if we have gotten path elements
+    edge_data = elements.get("edge", {}).get("data", None)
+    if edge_data is not None:
+        # try to convert the data in the PLY file to (n, 2) edge indexes
+        edges = None
+        if isinstance(edge_data, dict):
+            try:
+                edges = np.column_stack((edge_data["vertex1"], edge_data["vertex2"]))
+            except BaseException:
+                log.debug(
+                    f"failed to convert PLY edges from keys: {edge_data.keys()}",
+                    exc_info=True,
+                )
+        elif isinstance(edge_data, np.ndarray):
+            # is this the best way to check for a structured dtype?
+            if len(edge_data.shape) == 2 and edge_data.shape[1] == 2:
+                edges = edge_data
+            else:
+                # we could also check `edge_data.dtype.kind in 'OV'`
+                # but its not clear that that handles all the possibilities
+                edges = structured_to_unstructured(edge_data)
 
-        from ..path.exchange.misc import edges_to_path
-
-        edges = structured_to_unstructured(elements["edge"]["data"])
-        kwargs.update(edges_to_path(edges, kwargs["vertices"]))
+        if edges is not None:
+            from ..path.exchange.misc import edges_to_path
 
+            kwargs.update(edges_to_path(edges, kwargs["vertices"]))
     return kwargs
 
 
